<?php
/*
 * Presta
 *      IntellectMoney
 *
Last Changed Rev: 13433
Last Changed Date: 2012-02-08 19:52:31 +0400 (Wed, 08 Feb 2012)
 */
?>
<?php

class Intellectmoney extends PaymentModule
{
	private $_html = '';
	private $_postErrors = array();

	public function __construct()
	{
		$this->name = 'intellectmoney';
		$this->tab = 'payments_gateways';
		$this->version = '1.0';
		
		$this->currencies = true;
		$this->currencies_mode = 'radio';

		parent::__construct();

		$this->page = basename(__FILE__, '.php');
		$this->displayName = $this->l('IntellectMoney/VISA/MasterCard');
		$this->description = $this->l('Accepts payments by IntellectMoney/VISA/MasterCard');
		$this->confirmUninstall = $this->l('Are you sure you want to delete your details ?');
	}

	public function getIntellectMoneyUrl()
	{
		return 'https://merchant.intellectmoney.ru/ru/';
	}

	public function install()
	{
		if (!parent::install()
			OR !Configuration::updateValue('IM_ACCOUNT', '111111')
			OR !Configuration::updateValue('IM_KEY', '1234567890')
			OR !$this->registerHook('payment')
			OR !$this->registerHook('paymentReturn'))
			return false;
		return true;
	}

	public function uninstall()
	{
		if (!Configuration::deleteByName('IM_ACCOUNT')
			OR !Configuration::deleteByName('IM_KEY')
			OR !parent::uninstall())
			return false;
		return true;
	}

	public function getContent()
	{
		$this->_html = '<h2>IntellectMoney</h2>';
		if (isset($_POST['submitIM']))
		{
			if (empty($_POST['business']))
				$this->_postErrors[] = $this->l('IntellectMoney Shop ID is required.');
			if (empty($_POST['key']))
				$this->_postErrors[] = $this->l('IntellectMoney Shop KEY is required.');
			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('IM_ACCOUNT', strval($_POST['business']));
				Configuration::updateValue('IM_KEY', strval($_POST['key']));
				$this->displayConf();
			}
			else
				$this->displayErrors();
		}

		$this->displayIM();
		$this->displayFormSettings();
		return $this->_html;
	}

	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$this->l('Settings updated').'
		</div>';
	}

	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('There are') : $this->l('There is')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('errors') : $this->l('error')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}
	
	
	public function displayIM()
	{
		$this->_html .= '
		<img src="../modules/intellectmoney/intellectmoney.gif" style="float:left; margin-right:15px;" />
		<b>'.$this->l('This module allows you to accept payments by IntellectMoney.').'</b><br /><br />
		'.$this->l('If the client chooses this payment mode, your IntellectMoney account will be automatically credited.').'<br />
		'.$this->l('You need to configure your IntellectMoney account first before using this module.').'
		<div style="clear:both;">&nbsp;</div>';
	}

	public function displayFormSettings()
	{
		$conf = Configuration::getMultiple(array('IM_ACCOUNT', 'IM_KEY'));
		$business = array_key_exists('business', $_POST) ? $_POST['business'] : (array_key_exists('IM_ACCOUNT', $conf) ? $conf['IM_ACCOUNT'] : '');
		$key = array_key_exists('key', $_POST) ? $_POST['key'] : (array_key_exists('IM_KEY', $conf) ? $conf['IM_KEY'] : '');
		
		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post" style="clear: both;">
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Settings').'</legend>
			<label>'.$this->l('IntellectMoney Shop ID').'</label>
			<div class="margin-form"><input type="text" size="33" name="business" value="'.htmlentities($business, ENT_COMPAT, 'UTF-8').'" /></div>
			<label>'.$this->l('IntellectMoney Shop Key').'</label>
			<div class="margin-form"><input type="text" size="33" name="key" value="'.htmlentities($key, ENT_COMPAT, 'UTF-8').'" /></div>
			<br /><center><input type="submit" name="submitIM" value="'.$this->l('Update settings').'" class="button" /></center>
		</fieldset>
		</form><br /><br />
		<fieldset class="width3">
			<legend><img src="../img/admin/warning.gif" />'.$this->l('Information').'</legend>
			'.$this->l('Web-site of IntellectMoney').': <a target=_blank href=http://www.intellectmoney.ru>http://www.intellectmoney.ru</a><br>
		</fieldset>';
	}

	public function hookPayment($params)
	{
		if (!$this->active)
			return ;
		
		global $smarty;
		
		$address = new Address(intval($params['cart']->id_address_invoice));
		$customer = new Customer(intval($params['cart']->id_customer));
		$business = Configuration::get('IM_ACCOUNT');
		$currency = $this->getCurrency();
		$today = date("Y-m-d H:i:s");
		
		if (!Validate::isLoadedObject($address) OR !Validate::isLoadedObject($customer) OR !Validate::isLoadedObject($currency))
			return $this->l('IntellectMoney error: (invalid address or customer)');
		
		$products = $params['cart']->getProducts();
		
		foreach ($products as $key => $product)
		{
			$products[$key]['name'] = str_replace('"', '\'', $product['name']);
			if (isset($product['attributes']))
				$products[$key]['attributes'] = str_replace('"', '\'', $product['attributes']);
			$products[$key]['name'] = htmlentities(utf8_decode($product['name']));
			$products[$key]['imAmount'] = number_format(Tools::convertPrice($product['price_wt']/30, $currency), 2, '.', '');
		}
		$smarty->assign(array(
			'today' => $today,
			'customer' => $customer,
			'business' => $business,
			'currency' => $currency,
			'intellectMoneyUrl' => $this->getIntellectMoneyUrl(),
			// products + discounts - shipping cost
			'amount' => number_format(Tools::convertPrice($params['cart']->getOrderTotal(true, 4), $currency), 2, '.', ''),
			// shipping cost + wrapping
			'shipping' =>  number_format(Tools::convertPrice(($params['cart']->getOrderShippingCost() + $params['cart']->getOrderTotal(true, 6))/30, $currency), 2, '.', ''),
			'discounts' => $params['cart']->getDiscounts(),
			'products' => $products,
			// products + discounts + shipping cost
			'total' => number_format(Tools::convertPrice($params['cart']->getOrderTotal(true, 3), $currency), 2, '.', ''),
			'id_cart' => intval($params['cart']->id),
			'goBackUrl' => 'http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'order-confirmation.php?key='.$customer->secure_key.'&id_cart='.intval($params['cart']->id).'&id_module='.intval($this->id),
			'notify' => 'http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/intellectmoney/validation.php',
			'cancelUrl' => 'http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'index.php',
			'this_path' => $this->_path
		));
		
		return $this->display(__FILE__, 'intellectmoney.tpl');
	}

	public function hookPaymentReturn($params)
	{
		if (!$this->active)
			return ;
		
		return $this->display(__FILE__, 'confirmation.tpl');
	}

	public function getL($key)
	{
		$translations = array(
			'cart' => $this->l('Cart not found'),
			'order' => $this->l('Order has already been placed'),
		);
		return $translations[$key];
	}

	function validateOrder($id_cart, $id_order_state, $amountPaid, $paymentMethod = 'Unknown', $message = NULL, $extraVars = array(), $currency_special = NULL, $dont_touch_amount = false)
	{
		if (!$this->active)
			return ;
		
		//$currency = $this->getCurrency();
		//$cart = new Cart(intval($id_cart));
		//$cart->id_currency = $currency->id;
		//$cart->save();
		parent::validateOrder($id_cart, $id_order_state, $amountPaid, $paymentMethod, $message, $extraVars, $currency_special, true);
	}
}
